<?php

	class IDEALCHECKOUT_FOR_ZENCART_1_3_9
	{
		// Return the software name
		public static function getSoftwareName()
		{
			return 'ZenCart 1.3.9+';
		}


		// Return the software code
		public static function getSoftwareCode()
		{
			return str_replace('_', '-', substr(basename(__FILE__), 0, -4));
		}


		// Return path to main cinfig file (if any)
		public static function getConfigFile()
		{
			return SOFTWARE_PATH . DS . 'includes' . DS . 'configure.php';
		}


		// Return path to main cinfig file (if any)
		public static function getConfigData()
		{
			$sConfigFile = self::getConfigFile();

			// Detect DB settings via configuration file
			if(is_file($sConfigFile))
			{
				return file_get_contents($sConfigFile);
			}

			return '';
		}



		// Find default database settings
		public static function getDatabaseSettings($aSettings)
		{
			$aSettings['db_prefix'] = 'zen_';
			$sConfigData = self::getConfigData();

			if(!empty($sConfigData))
			{
				$aSettings['db_host'] = IDEALCHECKOUT_INSTALL::getFileValue($sConfigData, '/define\(\'DB_SERVER\', \'([^\']+)\'\);/');
				$aSettings['db_user'] = IDEALCHECKOUT_INSTALL::getFileValue($sConfigData, '/define\(\'DB_SERVER_USERNAME\', \'([^\']+)\'\);/');
				$aSettings['db_pass'] = IDEALCHECKOUT_INSTALL::getFileValue($sConfigData, '/define\(\'DB_SERVER_PASSWORD\', \'([^\']+)\'\);/');
				$aSettings['db_name'] = IDEALCHECKOUT_INSTALL::getFileValue($sConfigData, '/define\(\'DB_DATABASE\', \'([^\']+)\'\);/');
				$aSettings['db_prefix'] = IDEALCHECKOUT_INSTALL::getFileValue($sConfigData, '/define\(\'DB_PREFIX\', \'([^\']+)\'\);/');
				$aSettings['db_type'] = IDEALCHECKOUT_INSTALL::getFileValue($sConfigData, '/define\(\'DB_TYPE\', \'([^\']+)\'\);/');
			}

			return $aSettings;
		}



		// See if current software == self::$sSoftwareCode
		public static function isSoftware()
		{
			$aFiles = array();
			$aFiles[] = SOFTWARE_PATH . DS . 'includes' . DS . 'configure.php';
			$aFiles[] = SOFTWARE_PATH . DS . 'ipn_main_handler.php';
			$aFiles[] = SOFTWARE_PATH . DS . 'includes' . DS . 'classes' . DS . 'class.base.php';
			$aFiles[] = SOFTWARE_PATH . DS . 'includes' . DS . 'functions' . DS . 'functions_ezpages.php';
			$aFiles[] = SOFTWARE_PATH . DS . 'includes' . DS . 'version.php';

			foreach($aFiles as $sFile)
			{
				if(!is_file($sFile) && !is_dir($sFile))
				{
					return false;
				}
			}

			return true;
		}




		// Install plugin, return text
		public static function doInstall($aSettings)
		{
			IDEALCHECKOUT_INSTALL::doInstall($aSettings);


			$sql = "SELECT `configuration_key` FROM `" . $aSettings['db_prefix'] . "configuration` WHERE `configuration_key` = 'MODULE_PAYMENT_IDEALCHECKOUTIDEAL_STATUS' LIMIT 1;";
			if(!idealcheckout_database_isRecord($sql)) // See if key was already added
			{
				IDEALCHECKOUT_INSTALL::setLog('Adding records to table #_configuration.', __FILE__, __LINE__);

				$sql = "INSERT INTO `" . $aSettings['db_prefix'] . "configuration` (`configuration_title`, `configuration_key`, `configuration_value`, `configuration_description`, `configuration_group_id`, `sort_order`, `set_function`, `date_added`) values ('Enable Plugin', 'MODULE_PAYMENT_IDEALCHECKOUTIDEAL_STATUS', 'True', 'Accept iDEAL Payments', '6', '1', 'zen_cfg_select_option(array(\'True\', \'False\'), ', now());";
				idealcheckout_database_execute($sql);

				$sql = "INSERT INTO `" . $aSettings['db_prefix'] . "configuration` (`configuration_title`, `configuration_key`, `configuration_value`, `configuration_description`, `configuration_group_id`, `sort_order`, `date_added`) values ('Sort order', 'MODULE_PAYMENT_IDEALCHECKOUTIDEAL_SORT_ORDER', '0', 'Sort order of display. Lowest is displayed first.', '6', '0', now())";
				idealcheckout_database_execute($sql);

				$sql = "INSERT INTO `" . $aSettings['db_prefix'] . "configuration` (`configuration_title`, `configuration_key`, `configuration_value`, `configuration_description`, `configuration_group_id`, `sort_order`, `set_function`, `date_added`) values ('Enable Plugin', 'MODULE_PAYMENT_IDEALCHECKOUTMISTERCASH_STATUS', 'False', 'Accept Mister Cash Payments', '6', '1', 'zen_cfg_select_option(array(\'True\', \'False\'), ', now());";
				idealcheckout_database_execute($sql);

				$sql = "INSERT INTO `" . $aSettings['db_prefix'] . "configuration` (`configuration_title`, `configuration_key`, `configuration_value`, `configuration_description`, `configuration_group_id`, `sort_order`, `date_added`) values ('Sort order', 'MODULE_PAYMENT_IDEALCHECKOUTMISTERCASH_SORT_ORDER', '0', 'Sort order of display. Lowest is displayed first.', '6', '0', now())";
				idealcheckout_database_execute($sql);

				$sql = "INSERT INTO `" . $aSettings['db_prefix'] . "configuration` (`configuration_title`, `configuration_key`, `configuration_value`, `configuration_description`, `configuration_group_id`, `sort_order`, `set_function`, `date_added`) values ('Enable Plugin', 'MODULE_PAYMENT_IDEALCHECKOUTDIRECTEBANKING_STATUS', 'False', 'Accept Direct E-Banking Payments', '6', '0', 'zen_cfg_select_option(array(\'True\', \'False\'), ', now());";
				idealcheckout_database_execute($sql);

				$sql = "INSERT INTO `" . $aSettings['db_prefix'] . "configuration` (`configuration_title`, `configuration_key`, `configuration_value`, `configuration_description`, `configuration_group_id`, `sort_order`, `date_added`) values ('Sort order', 'MODULE_PAYMENT_IDEALCHECKOUTDIRECTEBANKING_SORT_ORDER', '0', 'Sort order of display. Lowest is displayed first.', '6', '0', now())";
				idealcheckout_database_execute($sql);

				$sql = "INSERT INTO `" . $aSettings['db_prefix'] . "configuration` (`configuration_title`, `configuration_key`, `configuration_value`, `configuration_description`, `configuration_group_id`, `sort_order`, `set_function`, `date_added`) values ('Enable Plugin', 'MODULE_PAYMENT_IDEALCHECKOUTCREDITCARD_STATUS', 'False', 'Accept Credit Card Payments', '6', '0', 'zen_cfg_select_option(array(\'True\', \'False\'), ', now());";
				idealcheckout_database_execute($sql);

				$sql = "INSERT INTO `" . $aSettings['db_prefix'] . "configuration` (`configuration_title`, `configuration_key`, `configuration_value`, `configuration_description`, `configuration_group_id`, `sort_order`, `date_added`) values ('Sort order', 'MODULE_PAYMENT_IDEALCHECKOUTCREDITCARD_SORT_ORDER', '0', 'Sort order of display. Lowest is displayed first.', '6', '0', now())";
				idealcheckout_database_execute($sql);

				$sql = "INSERT INTO `" . $aSettings['db_prefix'] . "configuration` (`configuration_title`, `configuration_key`, `configuration_value`, `configuration_description`, `configuration_group_id`, `sort_order`, `set_function`, `date_added`) values ('Enable Plugin', 'MODULE_PAYMENT_IDEALCHECKOUTPAYPAL_STATUS', 'False', 'Accept PayPal Payments', '6', '0', 'zen_cfg_select_option(array(\'True\', \'False\'), ', now());";
				idealcheckout_database_execute($sql);

				$sql = "INSERT INTO `" . $aSettings['db_prefix'] . "configuration` (`configuration_title`, `configuration_key`, `configuration_value`, `configuration_description`, `configuration_group_id`, `sort_order`, `date_added`) values ('Sort order', 'MODULE_PAYMENT_IDEALCHECKOUTPAYPAL_SORT_ORDER', '0', 'Sort order of display. Lowest is displayed first.', '6', '0', now())";
				idealcheckout_database_execute($sql);

				$sql = "INSERT INTO `" . $aSettings['db_prefix'] . "configuration` (`configuration_title`, `configuration_key`, `configuration_value`, `configuration_description`, `configuration_group_id`, `sort_order`, `set_function`, `date_added`) values ('Enable Plugin', 'MODULE_PAYMENT_IDEALCHECKOUTPAYSAFECARD_STATUS', 'False', 'Accept PaySafeCard Payments', '6', '0', 'zen_cfg_select_option(array(\'True\', \'False\'), ', now());";
				idealcheckout_database_execute($sql);

				$sql = "INSERT INTO `" . $aSettings['db_prefix'] . "configuration` (`configuration_title`, `configuration_key`, `configuration_value`, `configuration_description`, `configuration_group_id`, `sort_order`, `date_added`) values ('Sort order', 'MODULE_PAYMENT_IDEALCHECKOUTPAYSAFECARD_SORT_ORDER', '0', 'Sort order of display. Lowest is displayed first.', '6', '0', now())";
				idealcheckout_database_execute($sql);

				$sql = "INSERT INTO `" . $aSettings['db_prefix'] . "configuration` (`configuration_title`, `configuration_key`, `configuration_value`, `configuration_description`, `configuration_group_id`, `sort_order`, `set_function`, `date_added`) values ('Enable Plugin', 'MODULE_PAYMENT_IDEALCHECKOUTAUTHORIZEDTRANSFER_STATUS', 'False', 'Accept Authorized Transfer Payments', '6', '0', 'zen_cfg_select_option(array(\'True\', \'False\'), ', now());";
				idealcheckout_database_execute($sql);

				$sql = "INSERT INTO `" . $aSettings['db_prefix'] . "configuration` (`configuration_title`, `configuration_key`, `configuration_value`, `configuration_description`, `configuration_group_id`, `sort_order`, `date_added`) values ('Sort order', 'MODULE_PAYMENT_IDEALCHECKOUTAUTHORIZEDTRANSFER_SORT_ORDER', '0', 'Sort order of display. Lowest is displayed first.', '6', '0', now())";
				idealcheckout_database_execute($sql);

				$sql = "INSERT INTO `" . $aSettings['db_prefix'] . "configuration` (`configuration_title`, `configuration_key`, `configuration_value`, `configuration_description`, `configuration_group_id`, `sort_order`, `set_function`, `date_added`) values ('Enable Plugin', 'MODULE_PAYMENT_IDEALCHECKOUTMAESTRO_STATUS', 'False', 'Accept Maestro Payments', '6', '0', 'zen_cfg_select_option(array(\'True\', \'False\'), ', now());";
				idealcheckout_database_execute($sql);

				$sql = "INSERT INTO `" . $aSettings['db_prefix'] . "configuration` (`configuration_title`, `configuration_key`, `configuration_value`, `configuration_description`, `configuration_group_id`, `sort_order`, `date_added`) values ('Sort order', 'MODULE_PAYMENT_IDEALCHECKOUTMAESTRO_SORT_ORDER', '0', 'Sort order of display. Lowest is displayed first.', '6', '0', now())";
				idealcheckout_database_execute($sql);

				$sql = "INSERT INTO `" . $aSettings['db_prefix'] . "configuration` (`configuration_title`, `configuration_key`, `configuration_value`, `configuration_description`, `configuration_group_id`, `sort_order`, `set_function`, `date_added`) values ('Enable Plugin', 'MODULE_PAYMENT_IDEALCHECKOUTMANUALTRANSFER_STATUS', 'False', 'Accept Manual Transfer Payments', '6', '0', 'zen_cfg_select_option(array(\'True\', \'False\'), ', now());";
				idealcheckout_database_execute($sql);

				$sql = "INSERT INTO `" . $aSettings['db_prefix'] . "configuration` (`configuration_title`, `configuration_key`, `configuration_value`, `configuration_description`, `configuration_group_id`, `sort_order`, `date_added`) values ('Sort order', 'MODULE_PAYMENT_IDEALCHECKOUTMANUALTRANSFER_SORT_ORDER', '0', 'Sort order of display. Lowest is displayed first.', '6', '0', now())";
				idealcheckout_database_execute($sql);

				$sql = "INSERT INTO `" . $aSettings['db_prefix'] . "configuration` (`configuration_title`, `configuration_key`, `configuration_value`, `configuration_description`, `configuration_group_id`, `sort_order`, `set_function`, `date_added`) values ('Enable Plugin', 'MODULE_PAYMENT_IDEALCHECKOUTMASTERCARD_STATUS', 'False', 'Accept Mastercard Payments', '6', '0', 'zen_cfg_select_option(array(\'True\', \'False\'), ', now());";
				idealcheckout_database_execute($sql);

				$sql = "INSERT INTO `" . $aSettings['db_prefix'] . "configuration` (`configuration_title`, `configuration_key`, `configuration_value`, `configuration_description`, `configuration_group_id`, `sort_order`, `date_added`) values ('Sort order', 'MODULE_PAYMENT_IDEALCHECKOUTMASTERCARD_SORT_ORDER', '0', 'Sort order of display. Lowest is displayed first.', '6', '0', now())";
				idealcheckout_database_execute($sql);

				$sql = "INSERT INTO `" . $aSettings['db_prefix'] . "configuration` (`configuration_title`, `configuration_key`, `configuration_value`, `configuration_description`, `configuration_group_id`, `sort_order`, `set_function`, `date_added`) values ('Enable Plugin', 'MODULE_PAYMENT_IDEALCHECKOUTVISA_STATUS', 'False', 'Accept Visa Payments', '6', '0', 'zen_cfg_select_option(array(\'True\', \'False\'), ', now());";
				idealcheckout_database_execute($sql);

				$sql = "INSERT INTO `" . $aSettings['db_prefix'] . "configuration` (`configuration_title`, `configuration_key`, `configuration_value`, `configuration_description`, `configuration_group_id`, `sort_order`, `date_added`) values ('Sort order', 'MODULE_PAYMENT_IDEALCHECKOUTVISA_SORT_ORDER', '0', 'Sort order of display. Lowest is displayed first.', '6', '0', now())";
				idealcheckout_database_execute($sql);

				$sql = "INSERT INTO `" . $aSettings['db_prefix'] . "configuration` (`configuration_title`, `configuration_key`, `configuration_value`, `configuration_description`, `configuration_group_id`, `sort_order`, `set_function`, `date_added`) values ('Enable Plugin', 'MODULE_PAYMENT_IDEALCHECKOUTVPAY_STATUS', 'False', 'Accept vPay Payments', '6', '0', 'zen_cfg_select_option(array(\'True\', \'False\'), ', now());";
				idealcheckout_database_execute($sql);

				$sql = "INSERT INTO `" . $aSettings['db_prefix'] . "configuration` (`configuration_title`, `configuration_key`, `configuration_value`, `configuration_description`, `configuration_group_id`, `sort_order`, `date_added`) values ('Sort order', 'MODULE_PAYMENT_IDEALCHECKOUTVPAY_SORT_ORDER', '0', 'Sort order of display. Lowest is displayed first.', '6', '0', now())";
				idealcheckout_database_execute($sql);
			}



			IDEALCHECKOUT_INSTALL::setLog('Adding order staus "payment success" and "payment cancelled".', __FILE__, __LINE__);

			$sql = "SELECT `language_id` FROM `" . $aSettings['db_prefix'] . "languages` WHERE `code` = 'nl' LIMIT 1;";
			$aRecord = idealcheckout_database_getRecord($sql);

			if($aRecord)
			{
				$sql = "INSERT INTO `" . $aSettings['db_prefix'] . "orders_status` SET `orders_status_id` = '1000', `language_id` = '" . $aRecord['language_id'] . "', `orders_status_name` = 'Betaling succes';";
				idealcheckout_database_execute($sql);

				$sql = "INSERT INTO `" . $aSettings['db_prefix'] . "orders_status` SET `orders_status_id` = '1001', `language_id` = '" . $aRecord['language_id'] . "', `orders_status_name` = 'Betaling geannuleerd';";
				idealcheckout_database_execute($sql);
			}
			else
			{
				$sql = "INSERT INTO `" . $aSettings['db_prefix'] . "orders_status` SET `orders_status_id` = '1000', `language_id` = '1', `orders_status_name` = 'Payment success';";
				idealcheckout_database_execute($sql);

				$sql = "INSERT INTO `" . $aSettings['db_prefix'] . "orders_status` SET `orders_status_id` = '1001', `language_id` = '1', `orders_status_name` = 'Payment cancelled';";
				idealcheckout_database_execute($sql);
			}

			return true;
		}



		// Install plugin, return text
		public static function getInstructions($aSettings)
		{
			$sHtml = '';
			$sHtml .= '<ol>';
			$sHtml .= '<li>Log in op de beheeromgeving van uw webshop.</li>';
			$sHtml .= '<li>Klik in het hoofdmenu op Modules/Payment.<br>Hier vindt u alle toegevoegde betaalmethoden terug.</li>';
			$sHtml .= '<li>Klik de gewenste betaalmethode aan.</li>';
			$sHtml .= '<li>Klik vervolgens op de knop "install" (wordt rechts in het scherm getoond).</li>';
			$sHtml .= '<li>Herhaal stap 3 en 4 om alle gewenste betaalmethoden in te schakelen.</li>';
			$sHtml .= '</ol>';

			return $sHtml;
		}
	}

?>